Skip to main contentCrate bincake
Source - stream
- Writes all arguments to a byte buffer, taking each as a reference.
- vec8
- Initializes a vector with an 8-bit size.
- vec16
- Initializes a vector with a 16-bit size.
- vec32
- Initializes a vector with a 32-bit size.
- vec64
- Initializes a vector with a 64-bit size.
- vec128
- Initializes a vector with a 128-bit size.
- Tape
- A lightweight, zero-copy cursor over a slice.
- Vec8
- Vec16
- Vec32
- Vec64
- Vec128
- DecodeError
- Denotes a fatal error during decoding.
- EncodeError
- Denotes a fatal error during encoding.
- CharExt
- Read
- Canonical API for decoding data from a byte buffer.
- Serialize
- A value that can be serialized to and deserialized from a byte buffer.
- SliceExt
- ToTape
- Provides the convenience function
to_tape. - Write
- Canonical API for encoding data to a byte buffer.
- StringSize
- The type used to represent the length of a string when serialized.
- Serialize
- Derive macro for automatically implementing the
Serializable trait.