Skip to main contentCrate bincake
Source - vec8
- Initializes a vector with an 8-bit size.
- vec16
- Initializes a vector with an 16-bit size.
- vec32
- Initializes a vector with an 32-bit size.
- vec64
- Initializes a vector with an 64-bit size.
- vec128
- Initializes a vector with an 128-bit size.
- write_all
- Writes all provided data to the destination.
- write_le_num
- Writes a numeric value to the buffer in little-endian format.
- Tape
- A lightweight, zero-copy cursor over a slice.
- Vec8
- Vec16
- Vec32
- Vec64
- Vec128
- DecodeError
- Denotes a fatal error during decoding.
- EncodeError
- Denotes a fatal error during encoding.
- Read
- Serialize
- A value that can be serialized to and deserialized from a byte buffer.
- Write
- StringSize
- The type used to represent the length of a string when serialized.
- Serialize
- Derive macro for automatically implementing the
Serializable trait.